@@ -744,8 +744,8 @@ def parse_document_api_response(response: dict) -> Document:
 
 
 def parse_analyze_id_response(response):
-    document = _create_document_object(response)
     id_documents = []
+    response["Blocks"] = []
     for doc in response["IdentityDocuments"]:
         fields = {}
         for field in doc["IdentityDocumentFields"]:
@@ -756,7 +756,12 @@ def parse_analyze_id_response(response):
             }
         id_documents.append(IdentityDocument(fields))
         id_documents[-1].raw_object = doc
+        response["Blocks"].extend(doc.get("Blocks", []))
+    # FIXME: Quick fix, we need something more robust
+    document = parse_document_api_response(response)
+    del response["Blocks"]
     document.identity_documents = id_documents
+    document.response = response
     return document
 
 
@@ -794,15 +799,13 @@ def create_expense_from_field(field: Dict, page: Page) -> ExpenseField:
 
 
 def parser_analyze_expense_response(response):
-    document = _create_document_object(response)
-
-    pages = [
-        Page(str(uuid.uuid4()), document.width, document.height, page_num=page_num + 1)
-        for page_num in range(response["DocumentMetadata"]["Pages"])
-    ]
+    response["Blocks"] = [b for doc in response["ExpenseDocuments"] for b in doc.get("Blocks", [])]
+    document = parse_document_api_response(response)
     for doc in response["ExpenseDocuments"]:
         # FIXME
-        page = pages[doc["SummaryFields"][0]["PageNumber"] - 1]
+        if len(doc["SummaryFields"]) == 0:
+            continue
+        page = document.pages[doc["SummaryFields"][0]["PageNumber"] - 1]
         summary_fields = []
         for summary_field in doc["SummaryFields"]:
             summary_fields.append(create_expense_from_field(summary_field, page))
@@ -819,10 +822,11 @@ def parser_analyze_expense_response(response):
             summary_fields=summary_fields, line_item_fields=line_item_groups
         )
         expense_document.raw_object = doc
-        pages[summary_field["PageNumber"] - 1].expense_documents.append(
+        document.pages[summary_field["PageNumber"] - 1].expense_documents.append(
             expense_document
         )
-    document.pages.extend(pages)
+    del response["Blocks"]
+    document.response = response
     return document
 
 
